from invoke import run, task


@task
def clean():
    run('cd docs && make clean')


@task
def docs():
    run('cd docs && make html')


@task
def foreman():
    run('foreman start -f Procfile.dev')


@task
def pypi():
    run('python setup.py sdist')
    run('python setup.py bdist_wheel')


@task
def pypi_upload():
    run('python setup.py sdist upload')
    run('python setup.py bdist_wheel upload')


@task
def test():
    run('py.test '
        '--cov-report term-missing '
        '--cov tests/test_requests_forecast.py')



from setuptools import setup, find_packages


with open('README.rst') as f:
    readme = f.read()

with open('LICENSE') as f:
    license = f.read()

setup(
    name='requests-forecast',
    license='BSD',
    version='0.4.0',
    description='A minimalist Forecast.io API client.',
    long_description=readme,
    author='Jeff Triplett',
    author_email='jeff.triplett@gmail.com',
    url='https://github.com/jefftriplett/requests-forecast',
    py_modules=['requests_forecast'],
    install_requires=['requests>=1.2', 'pytz'],
    packages=find_packages(),
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)
